@@ -86,7 +86,7 @@
 #define KBOOKMARKS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KBOOKMARKS_NO_DEPRECATED
-#  define KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
+#  define KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef KBOOKMARKS_NO_DEPRECATED_WARNINGS
 #  define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE 0x55f00
+#    define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
@@ -192,7 +192,7 @@
 #define KBOOKMARKS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KBOOKMARKS_NO_DEPRECATED
-#  define KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55f00
+#  define KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef KBOOKMARKS_NO_DEPRECATED_WARNINGS
 #  define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE 0
@@ -202,7 +202,7 @@
 #  ifdef KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE 0x55f00
+#    define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
